@@ -1,7 +1,7 @@
 package Minion::Backend::Mango;
 use Mojo::Base 'Minion::Backend';
 
-our $VERSION = '0.96';
+our $VERSION = '0.97';
 
 use Mango;
 use Mango::BSON qw(bson_oid bson_time bson_doc);
@@ -413,9 +413,22 @@ Reset job queue.
 =head2 retry_job
 
   my $bool = $backend->retry_job($job_id);
+  my $bool = $backend->retry_job($job_id, {delay => 10});
 
 Transition from C<failed> or C<finished> state back to C<inactive>.
 
+These options are currently available:
+
+=over 2
+
+=item delay
+
+  delay => 10
+
+Delay job for this many seconds (from now).
+
+=back
+
 =head2 stats
 
   my $stats = $backend->stats;
